@@ -60,7 +60,7 @@ count_levels <- function(dat, enum_list, hasNA= c("no", "count.obs", "count.miss
     # 8/9/2016 -- needed since clusterExport does not work with non exported functions
     # See: http://stackoverflow.com/questions/38836341
     count_compare <- imputeMulti:::count_compare 
-    parallel::clusterExport(cl, varlist= c("count_compare"))
+    parallel::clusterExport(cl, varlist= c("count_compare"), envir= 1)
     
     temp <- do.call("cbind", parallel::clusterApply(cl,
           # split data across clusters, share: comparison (e2) and hasNA
